==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/fi.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Salasanan tulee olle vähintään %s merkkiä pitkä",
    "Password needs to contain at least one lower and one upper case character." : "Salasanan tulee sisältää vähintään yksi pieni ja yksi iso kirjain.",
    "Password needs to contain at least one numeric character." : "Salasanassa tulee olla vähintään yksi numeerinen merkki.",
    "Password needs to contain at least one special character." : "Salasanassa tulee olla vähintään yksi erikoismerkki.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Salasana on yksi miljoonasta yleisimmästä. Tee salasanasta erikoisempi.",
    "Password is present in compromised password list. Please choose a different password." : "Salasana kuuluu murrettujen salasanojen listalle. Valitse eri salasana.",
    "Password policy" : "Salasanakäytäntö",
    "Minimal length" : "Vähimmäispituus",
    "Forbid common passwords" : "Kiellä yleisimmät salasanat",
    "Enforce upper and lower case characters" : "Pakota käyttämään isoja ja pieniä kirjaimia",
    "Enforce numeric characters" : "Pakota käyttämään numeroita",
    "Enforce special characters" : "Pakota käyttämään erikoismerkkejä",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Tarkista salasanan vastaavuus haveibeenpwned.comin keräämiin vuotaneisiin salasanoihin",
    "Password need to be at least %s characters long" : "Salasanan tulee olla vähintään %s merkkiä pitkä",
    "Password need to contain at least one lower case character and one upper case character." : "Salasanan tulee sisältää vähintään yksi pieni ja yksi iso kirjain.",
    "Password need to contain at least one numeric character." : "Salasanan tulee sisältää vähintään yksi numero.",
    "Password need to contain at least one special character." : "Salasanan tulee sisältää vähintään yksi erikoismerkki.",
    "Password is within the 1,000,000 most common passwords. Please choose another one." : "Salasana on yksi 1 000 000 yleisimmästä salasanasta. Valitse jokin muu salasana.",
    "Check password against the list of breached passwords from haveibeenpwnd.com" : "Vertaa salasanaa haveibeenpwnd.com-palvelun tuottamaa murrettujen salasanojen listaa vasten"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/password_policy/l10n/fi.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password needs to be at least %s characters long" : "Salasanan tulee olle vähintään %s merkkiä pitkä",
    "Password needs to contain at least one lower and one upper case character." : "Salasanan tulee sisältää vähintään yksi pieni ja yksi iso kirjain.",
    "Password needs to contain at least one numeric character." : "Salasanassa tulee olla vähintään yksi numeerinen merkki.",
    "Password needs to contain at least one special character." : "Salasanassa tulee olla vähintään yksi erikoismerkki.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Salasana on yksi miljoonasta yleisimmästä. Tee salasanasta erikoisempi.",
    "Password is present in compromised password list. Please choose a different password." : "Salasana kuuluu murrettujen salasanojen listalle. Valitse eri salasana.",
    "Password policy" : "Salasanakäytäntö",
    "Allows admins to configure a password policy" : "Mahdollistaa ylläpitäjien määrittää salasanakäytännön",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Salli ylläpitäjän määrittää ennalta määritettyjä ehtoja salasanalle, esimerkiksi vähimmäispituuden",
    "Minimal length" : "Vähimmäispituus",
    "Forbid common passwords" : "Kiellä yleisimmät salasanat",
    "Enforce upper and lower case characters" : "Pakota käyttämään isoja ja pieniä kirjaimia",
    "Enforce numeric characters" : "Pakota käyttämään numeroita",
    "Enforce special characters" : "Pakota käyttämään erikoismerkkejä",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Tarkista salasanan vastaavuus haveibeenpwned.comin keräämiin vuotaneisiin salasanoihin"
},
"nplurals=2; plural=(n != 1);");
